==> aws-java-sdk-ecs-1.10.61-sources.jar: com/amazonaws/services/ecs/model/transform/ListTaskDefinitionFamiliesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ecs.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.ecs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ListTaskDefinitionFamiliesRequest Marshaller
 */
public class ListTaskDefinitionFamiliesRequestMarshaller
        implements
        Marshaller<Request<ListTaskDefinitionFamiliesRequest>, ListTaskDefinitionFamiliesRequest> {

    public Request<ListTaskDefinitionFamiliesRequest> marshall(
            ListTaskDefinitionFamiliesRequest listTaskDefinitionFamiliesRequest) {

        if (listTaskDefinitionFamiliesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListTaskDefinitionFamiliesRequest> request = new DefaultRequest<ListTaskDefinitionFamiliesRequest>(
                listTaskDefinitionFamiliesRequest, "AmazonECS");
        request.addHeader("X-Amz-Target",
                "AmazonEC2ContainerServiceV20141113.ListTaskDefinitionFamilies");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            StringWriter stringWriter = new StringWriter();
            JSONWriter jsonWriter = new JSONWriter(stringWriter);

            jsonWriter.object();

            if (listTaskDefinitionFamiliesRequest.getFamilyPrefix() != null) {
                jsonWriter.key("familyPrefix").value(
                        listTaskDefinitionFamiliesRequest.getFamilyPrefix());
            }
            if (listTaskDefinitionFamiliesRequest.getNextToken() != null) {
                jsonWriter.key("nextToken").value(
                        listTaskDefinitionFamiliesRequest.getNextToken());
            }
            if (listTaskDefinitionFamiliesRequest.getMaxResults() != null) {
                jsonWriter.key("maxResults").value(
                        listTaskDefinitionFamiliesRequest.getMaxResults());
            }

            jsonWriter.endObject();

            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-ecs-1.10.63-sources.jar: com/amazonaws/services/ecs/model/transform/ListTaskDefinitionFamiliesRequestMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ecs.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import static com.amazonaws.util.StringUtils.COMMA_SEPARATOR;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.ecs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ListTaskDefinitionFamiliesRequest Marshaller
 */
public class ListTaskDefinitionFamiliesRequestMarshaller
        implements
        Marshaller<Request<ListTaskDefinitionFamiliesRequest>, ListTaskDefinitionFamiliesRequest> {

    public Request<ListTaskDefinitionFamiliesRequest> marshall(
            ListTaskDefinitionFamiliesRequest listTaskDefinitionFamiliesRequest) {

        if (listTaskDefinitionFamiliesRequest == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        Request<ListTaskDefinitionFamiliesRequest> request = new DefaultRequest<ListTaskDefinitionFamiliesRequest>(
                listTaskDefinitionFamiliesRequest, "AmazonECS");
        request.addHeader("X-Amz-Target",
                "AmazonEC2ContainerServiceV20141113.ListTaskDefinitionFamilies");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final SdkJsonGenerator jsonGenerator = new SdkJsonGenerator();

            jsonGenerator.writeStartObject();

            if (listTaskDefinitionFamiliesRequest.getFamilyPrefix() != null) {
                jsonGenerator.writeFieldName("familyPrefix").writeValue(
                        listTaskDefinitionFamiliesRequest.getFamilyPrefix());
            }
            if (listTaskDefinitionFamiliesRequest.getNextToken() != null) {
                jsonGenerator.writeFieldName("nextToken").writeValue(
                        listTaskDefinitionFamiliesRequest.getNextToken());
            }
            if (listTaskDefinitionFamiliesRequest.getMaxResults() != null) {
                jsonGenerator.writeFieldName("maxResults").writeValue(
                        listTaskDefinitionFamiliesRequest.getMaxResults());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length",
                    Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.1");
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
